@@ -5,38 +5,87 @@ use warnings;
 
 use Carp;
 use Object::InsideOut;
-use XML::Simple;
+use XML::LibXML;
 use WWW::Ohloh::API::KudoScore;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
+
+use overload '""' => sub { $_[0]->name };
 
 my @request_url_of  :Field  :Arg(request_url)  :Get( request_url );
 my @xml_of  :Field :Arg(xml);   
 
-sub as_xml { my $self = shift; return XMLout( $xml_of[ $$self ], 
-            RootName => 'account', NoAttr => 1 ); }
+my @id_of :Field :Set(_set_id) :Get(id);
+my @name_of :Field :Set(_set_name) :Get(name);
+my @creation_date_of :Field :Set(_set_created_at) :Get(created_at);
+my @update_date_of :Field :Set(_set_updated_at) :Get(updated_at);
+my @homepage_url_of :Field :Set(_set_homepage_url) :Get(homepage_url);
+my @avatar_url_of :Field :Set(_set_avatar_url) :Get(avatar_url);
+my @posts_count_of :Field :Set(_set_posts_count) :Get(posts_count);
+my @location_of :Field :Set(_set_location) :Get(location);
+my @latitude_of :Field :Set(_set_latitude) :Get(latitude);
+my @longitude_of :Field :Set(_set_longitude) :Get(longitude);
+my @country_code_of :Field :Set(_set_country_code) :Get(country_code);
+my @kudo_of :Field Set(_set_kudo) :Get(kudo_score);
+
+#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+sub _init :Init {
+    my $self = shift;
+
+    my $dom = $xml_of[ $$self ] or return;
+
+    $self->_set_id( $dom->findvalue( 'id/text()' ) );
+    $self->_set_name( $dom->findvalue( 'name/text()' ) );
+    $self->_set_created_at( $dom->findvalue( 'created_at/text()' ) );
+    $self->_set_updated_at( $dom->findvalue( 'updated_at/text()' ) );
+    $self->_set_homepage_url( $dom->findvalue( 'homepage_url/text()' ) );
+    $self->_set_avatar_url( $dom->findvalue( 'avatar_url/text()' ) );
+    $self->_set_posts_count( $dom->findvalue( 'posts_count/text()' ) );
+    $self->_set_location( $dom->findvalue( 'location/text()' ) );
+    $self->_set_country_code( $dom->findvalue( 'country_code/text()' ) );
+    $self->_set_latitude( $dom->findvalue( 'latitude/text()' ) );
+    $self->_set_longitude( $dom->findvalue( 'longitude/text()' ) );
+
+    if( my( $node ) = $dom->findnodes( 'kudo_score[1]' ) ) {
+        $kudo_of[ $$self ] 
+            = WWW::Ohloh::API::KudoScore->new( xml => $node );
+    }
+}
+
+sub as_xml { 
+    my $self = shift; 
+    my $xml;
+    my $w = XML::Writer->new( OUTPUT => \$xml );
+
+    $w->startTag( 'account' );
+    
+    $w->dataElement( id => $self->id );
+    $w->dataElement( name => $self->name );
+    $w->dataElement( created_at => $self->created_at );
+    $w->dataElement( updated_at => $self->updated_at );
+    $w->dataElement( homepage_url => $self->homepage_url );
+    $w->dataElement( avatar_url => $self->avatar_url );
+    $w->dataElement( posts_count => $self->posts_count );
+    $w->dataElement( location => $self->location );
+    $w->dataElement( country_code => $self->country_code );
+    $w->dataElement( latitude => $self->latitude );
+    $w->dataElement( longitude => $self->longitude );
+
+    $xml .= $self->kudo->as_xml if $self->kudo;
+
+    $w->endTag;
+
+    return $xml; 
+}
 
 sub kudoScore {
     my $self = shift;
-    
-    my $kudo = $xml_of[ $$self ]->{kudo_score} or return;
-
-    return WWW::Ohloh::API::KudoScore->new( xml => $kudo );
+    return $kudo_of[ $$self ];
 }
 
 # aliases
-*kudo = *kudo_score = *kudoScore;
-
-for my $attr ( qw/ id name created_at updated_at homepage_url
-                    avatar_url posts_count location country_code
-                    latitude longitude / ) {
-    eval <<"END_SUB";
-        sub $attr {
-            my \$self = shift;
-            return \$xml_of[ \$\$self ]->{$attr};
-        }
-END_SUB
-}
+*kudo = *kudoScore;
 
 'end of WWW::Ohloh::API::Account';
 __END__
@@ -127,6 +176,13 @@ as an XML string.  Note that this is not the exact xml document as returned
 by the Ohloh server: due to the current XML parsing module used
 by W::O::A (to wit: L<XML::Simple>), the ordering of the nodes can differ.
 
+=head1 OVERLOADING
+
+When the object is called in a string context, it'll be replaced by
+the name associated with the account. E.g.,
+
+    print $account;  # equivalent to 'print $account->name'
+
 =head1 SEE ALSO
 
 =over
@@ -147,7 +203,7 @@ Ohloh Account API reference: http://www.ohloh.net/api/reference/account
 
 =head1 VERSION
 
-This document describes WWW::Ohloh::API version 0.0.1
+This document describes WWW::Ohloh::API version 0.0.2
 
 =head1 BUGS AND LIMITATIONS
 
