@@ -5,27 +5,50 @@ use warnings;
 
 use Carp;
 use Object::InsideOut;
-use XML::Simple;
+use XML::LibXML;
+use XML::Writer;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 my @xml_of :Field :Arg(xml);
 
-sub as_xml { my $self = shift; return XMLout( $xml_of[ $$self ], 
-            RootName => 'kudo_score', NoAttr => 1 ); }
+my @creation_time_of :Field  :Get(created_at) :Set(_set_created_at);
+my @kudo_rank_of  :Field :Get(kudo_rank) :Set(_set_kudo_rank);
+my @position_of :Field  :Get(position) :Set(_set_position);
+my @max_position_of :Field  :Get(max_position) :Set(_set_max_position);
+my @position_delta_of :Field  :Get(position_delta) :Set(_set_position_delta);
 
-for my $attr ( qw/ created_at kudo_rank position max_position 
-                    position_delta / ) {
-    eval <<"END_SUB";
-        sub $attr {
-            my \$self = shift;
-            return \$xml_of[ \$\$self ]->{$attr};
-        }
-END_SUB
+sub _init :Init {
+    my $self = shift;
+
+    my $dom = $xml_of[ $$self ] or return;
+
+    $self->_set_created_at( $dom->findvalue( 'created_at/text()' ) );
+    $self->_set_kudo_rank( $dom->findvalue( 'kudo_rank/text()' ) );
+    $self->_set_position( $dom->findvalue( 'position/text()' ) );
+    $self->_set_max_position( $dom->findvalue( 'max_position/text()' ) );
+    $self->_set_position_delta( $dom->findvalue( 'position_delta/text()' ) );
 }
 
+# aliases
 *rank = *kudo_rank;
 
+sub as_xml { 
+    my $self = shift; 
+    my $xml;
+    my $w = XML::Writer->new( OUTPUT => \$xml );
+
+    $w->startTag( 'kudo_score' );
+    $w->dataElement( 'created_at', $self->created_at );
+    $w->dataElement( 'kudo_rank', $self->kudo_rank );
+    $w->dataElement( 'position', $self->position );
+    $w->dataElement( 'max_position', $self->max_position );
+    $w->dataElement( 'position_delta', $self->position_delta );
+    $w->endTag;
+
+    return $xml;
+}
+
 'end of WWW::Ohloh::API::KudoScore';
 __END__
 
@@ -106,7 +129,7 @@ Ohloh Account API reference: http://www.ohloh.net/api/reference/kudo_score
 
 =head1 VERSION
 
-This document describes WWW::Ohloh::API version 0.0.1
+This document describes WWW::Ohloh::API version 0.0.2
 
 =head1 BUGS AND LIMITATIONS
 
